use Lingua::Sinica::PerlYuYan;

註俄農式乘法
無警兮

          用
         通兮
        副俄農
       始吾起純
      衰又純添合
     賦諸兮吾純果
    兮當起純衰大壹
   合始純衰賦整純衰
  除貳兮純添賦貳乘純
 添兮純果賦純果加純添
倘壹等純衰模貳終純果終

use Test::More tests => 1;
is 俄農(18,23), 414;
